==> apache-camel-3.15.0-src.zip: apache-camel-3.15.0/components/camel-azure/camel-azure-servicebus/src/main/java/org/apache/camel/component/azure/servicebus/ServiceBusEndpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.azure.servicebus;

import org.apache.camel.Category;
import org.apache.camel.Component;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.spi.UriEndpoint;
import org.apache.camel.spi.UriParam;
import org.apache.camel.support.DefaultEndpoint;

/**
 * Send and receive messages to/from Azure Event Bus.
 */
@UriEndpoint(firstVersion = "3.12.0", scheme = "azure-servicebus", title = "Azure ServiceBus",
             syntax = "azure-servicebus:topicOrQueueName", category = {
                     Category.CLOUD, Category.MESSAGING })
public class ServiceBusEndpoint extends DefaultEndpoint {

    @UriParam
    private ServiceBusConfiguration configuration;

    public ServiceBusEndpoint(final String uri, final Component component, final ServiceBusConfiguration configuration) {
        super(uri, component);
        this.configuration = configuration;
    }

    @Override
    public Producer createProducer() throws Exception {
        return new ServiceBusProducer(this);
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        final Consumer eventHubConsumer = new ServiceBusConsumer(this, processor);
        configureConsumer(eventHubConsumer);

        return eventHubConsumer;
    }

    /**
     * The component configurations
     */
    public ServiceBusConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(ServiceBusConfiguration configuration) {
        this.configuration = configuration;
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-azure/camel-azure-servicebus/src/main/java/org/apache/camel/component/azure/servicebus/ServiceBusEndpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.azure.servicebus;

import java.util.Map;

import org.apache.camel.Category;
import org.apache.camel.Component;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.component.azure.servicebus.client.ServiceBusClientFactory;
import org.apache.camel.spi.EndpointServiceLocation;
import org.apache.camel.spi.UriEndpoint;
import org.apache.camel.spi.UriParam;
import org.apache.camel.support.DefaultEndpoint;
import org.apache.camel.util.ObjectHelper;

/**
 * Send and receive messages to/from Azure Service Bus.
 */
@UriEndpoint(firstVersion = "3.12.0", scheme = "azure-servicebus", title = "Azure ServiceBus",
             syntax = "azure-servicebus:topicOrQueueName", category = {
                     Category.CLOUD, Category.MESSAGING },
             headersClass = ServiceBusConstants.class)
public class ServiceBusEndpoint extends DefaultEndpoint implements EndpointServiceLocation {

    @UriParam
    private ServiceBusConfiguration configuration;
    private ServiceBusClientFactory serviceBusClientFactory = new ServiceBusClientFactory();

    public ServiceBusEndpoint(final String uri, final Component component, final ServiceBusConfiguration configuration) {
        super(uri, component);
        this.configuration = configuration;
    }

    @Override
    public Producer createProducer() throws Exception {
        return new ServiceBusProducer(this);
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        final Consumer eventHubConsumer = new ServiceBusConsumer(this, processor);
        configureConsumer(eventHubConsumer);

        return eventHubConsumer;
    }

    /**
     * The component configurations
     */
    public ServiceBusConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(ServiceBusConfiguration configuration) {
        this.configuration = configuration;
    }

    /**
     * Set to use a custom client factory
     */
    public ServiceBusClientFactory getServiceBusClientFactory() {
        return serviceBusClientFactory;
    }

    public void setServiceBusClientFactory(ServiceBusClientFactory serviceBusClientFactory) {
        this.serviceBusClientFactory = serviceBusClientFactory;
    }

    @Override
    public String getServiceUrl() {
        if (ObjectHelper.isNotEmpty(configuration.getFullyQualifiedNamespace())) {
            return configuration.getFullyQualifiedNamespace();
        }
        return null;
    }

    @Override
    public String getServiceProtocol() {
        return "servicebus";
    }

    @Override
    public Map<String, String> getServiceMetadata() {
        if (configuration.getTopicOrQueueName() != null) {
            return Map.of("topic-or-queue-name", configuration.getTopicOrQueueName());
        }
        return null;
    }
}
